/*
 *    Linux/68k Frame Buffer Device Configuration
 *
 *     Copyright 1995 by Geert Uytterhoeven
 *                       (Geert.Uytterhoeven@cs.kuleuven.ac.be)
 *
 *    --------------------------------------------------------------------------
 *
 *    This file is subject to the terms and conditions of the GNU General Public
 *    License. See the file COPYING in the main directory of the Linux/68k
 *    distribution for more details.
 */


%{

#include <stdio.h>
#include <ctype.h>

#include "fbset.h"

extern int yylex(void);
extern void yyerror(char *s);


struct VideoMode VideoMode;

void ClearVideoMode(void)
{
   memset(&VideoMode, 0, sizeof(VideoMode));
}

%}

%start file

%token MONSPECS MODE GEOMETRY TIMINGS HSYNC VSYNC CSYNC EXTSYNC BCAST LACED
       DOUBLE ENDMODE POLARITY BOOLEAN STRING NUMBER

%%

file     :  monspecs vmodes
         ;

monspecs :  MONSPECS NUMBER NUMBER NUMBER NUMBER
            {
               MonSpecs.MinHrate = $2;
               MonSpecs.MaxHrate = $3;
               MonSpecs.MinVrate = $4;
               MonSpecs.MaxVrate = $5;
               ClearVideoMode();
            }
         ;

vmodes   :  vmode
         |  vmodes vmode
         ;

vmode    :  MODE STRING geometry timings options ENDMODE
            {
               VideoMode.name = (char *)$2;
               AddVideoMode(&VideoMode);
               ClearVideoMode();
            }
         ;

geometry :  GEOMETRY NUMBER NUMBER NUMBER NUMBER NUMBER
            {
               VideoMode.geometry.xres = $2;
               VideoMode.geometry.yres = $3;
               VideoMode.geometry.vxres = $4;
               VideoMode.geometry.vyres = $5;
               VideoMode.geometry.depth = $6;
            }
         ;

timings  :  TIMINGS NUMBER NUMBER NUMBER NUMBER NUMBER NUMBER NUMBER
            {
               VideoMode.timings.pixclock = $2;
               VideoMode.timings.left = $3;
               VideoMode.timings.right = $4;
               VideoMode.timings.upper = $5;
               VideoMode.timings.lower = $6;
               VideoMode.timings.hslen = $7;
               VideoMode.timings.vslen = $8;
            }
         ;

options  :  /* empty */
         |  options hsync
         |  options vsync
         |  options csync
         |  options extsync
         |  options bcast
         |  options laced
         |  options double
         ;

hsync    :  HSYNC POLARITY
            {
               VideoMode.options.hsync = $2;
            }
         ;

vsync    :  VSYNC POLARITY
            {
               VideoMode.options.vsync = $2;
            }
         ;

csync    :  CSYNC POLARITY
            {
               VideoMode.options.csync = $2;
            }
         ;

extsync  :  EXTSYNC BOOLEAN
            {
               VideoMode.options.extsync = $2;
            }
         ;

bcast    :  BCAST BOOLEAN
            {
               VideoMode.options.bcast = $2;
            }
         ;

laced    :  LACED BOOLEAN
            {
               VideoMode.options.laced = $2;
            }
         ;

double   :  DOUBLE BOOLEAN
            {
               VideoMode.options.dblscan = $2;
            }
         ;

%%
